local Local = {}
---[[-----------------------------------------------------------
-- Section I: Local Constants                     	      --
----------------------------------------------------------------
-- Note: These are just regular variables, but shouldn't be changed runtime.
local lcDEFAULT_OPTIONS = {
	LowHealthThreshold 		= 0.4,
	CritHealthThreshold 		= 0.2,
	LowManaThreshold		= 0.4,
	CritManaThreshold		= 0.2,
	HealthPartyWatch		= TRUE,
	HealthPetWatch			= FALSE,
	LowHealthPartySpam		= FALSE,
	CritHealthPartySpam		= FALSE,
	LowHealthPartyMsg		= VitalWatchLocale.DEFAULT_LowHealthPartyMsg,
	CritHealthPartyMsg		= VitalWatchLocale.DEFAULT_CritHealthPartyMsg,
	LowManaPartyMsg			= VitalWatchLocale.DEFAULT_LowManaPartyMsg,
	CritManaPartyMsg		= VitalWatchLocale.DEFAULT_CritManaPartyMsg,
	LowHealthEmote			= VitalWatchLocale.DEFAULT_LowHealthEmote,
	CritHealthEmote			= VitalWatchLocale.DEFAULT_CritHealthEmote,
	LowManaEmote			= VitalWatchLocale.DEFAULT_LowManaEmote,
	CritManaEmote			= VitalWatchLocale.DEFAULT_CritManaEmote,
	LowHealthSound			= "blip5.wav",
	CritHealthSound			= "phasers3.wav",
	LowManaSound			= "hitom.wav",
	CritManaSound			= "lotom.wav",
	NoError				= FALSE
}

---[[-----------------------------------------------------------
-- Section II: Local Variables                     	      --
----------------------------------------------------------------

-- These colours will be used when displaying the floating messages
Local.LowHealthColour  	= "yellow"
Local.CritHealthColour 	= "red"
Local.LowManaColour 	= "cyan"
Local.CritManaColour 	= "blue"

-- These tables will be used to store values gotten from the last event update
Local.LastHealthPercentage = {}
Local.LastManaPercentage = {}

---[[-----------------------------------------------------------
-- Section III: Initialize the Addon Object.                   --
----------------------------------------------------------------

-- See the "Ace Usage Guide.txt" document in the development kit for explanations of
-- each of the following parameters.
VitalWatch = AceAddon:new({
    name          = VitalWatchLocale.Title,
    description   = VitalWatchLocale.Desc, -- Optional; Ace will use the .toc Notes text
    version       = VitalWatchLocale.Version,
    releaseDate   = "12-1-2005",
    aceCompatible = "102", -- Check ACE_COMP_VERSION in Ace.lua for current.
    author        = "Thrae",
    email         = "spamreceiver1@umbc.edu",
    website       = "http://www.wowace.com",
    category      = "combat",
    --optionsFrame  = "VitalWatchOptionsFrame",
    db            = AceDatabase:new("VitalWatchDB"),
    defaults      = lcDEFAULT_OPTIONS,
    cmd           = AceChatCmd:new(VitalWatchLocale.ChatCmd, VitalWatchLocale.ChatOptions)
})

-- Register common functions with AceUtil.
ace:RegisterFunctions( VitalWatch, {
	version = 1.02,
	
	Msg   = function(self, ...)
      		self.cmd:msg(unpack(arg))
   	end,
   	Get   = function(self, var)
      		return self.db:get(self.profilePath, var)
   	end,
   	Set   = function(self, var, val, chat)
      		self.db:set(self.profilePath, var, val)
   	end,	
   	Toggle   = function(self, var, chat)
      		self.cmd:status(chat, self.db:toggle(self.profilePath, var), ACEG_MAP_ONOFF) 
   	end,
-- 	GetP  = function({self, p}, var)
--      		return self.db:get(self.profilePath, var)
--   	end,
--   	SetP  = function({self, p}. var, val)
--      		self.db:set(self.profilePath, var, val)
--   	end,
--   	TogP  = function({self, p}, var, chat)
--      		self.cmd:result(format(chat, self.db:toggle(
--      		self.profilePath, var) and ACEG_ON or ACEG_OFF))
--   	end,
   	Err   = function(self, inp, real)
      		self.cmd:error(ACEG_ERROR, inp, real)
   	end,
   	Inp   = function(self, inp, main, var)
      		self:Set(var, inp) self:Msg(main, inp)
   	end,
   	Ins   = function(self, db, val)
      		self.db:insert(self.profilePath, db, val)
   	end,
   	Del   = function(self, db, num)
      		self.db:remove(self.profilePath, db, num)
   	end,
	Reset = function(self, i)
		if i == "" then self.cmd:msg(ACEG_RESETINFO,
			self.cmd._cmdList[1])
		else self.cmd:msg(ACEG_DORESET)
			self.db:reset(self.profilePath,
					self.defaults)
		end
	end,
    	ReportMsg = function(self, val, text) 
		if not val or val == TRUE then 
			self.cmd:status(text, val, ACEG_MAP_ONOFF) 
		else 
			self.cmd:status(text, val) 
		end 
	end,
	ReportMap = function(self, map)
		for k,v in map do 
			self:ReportMsg( self.db:get(self.profilePath, k), v )
		end
	end
})

function VitalWatch:Initialize()
	
    -- Stylized reporting tools.


    -- Local variables
    Local.LastHealthPercentage["player"] = UnitHealth("player") / UnitHealthMax("player")
    Local.LastHealthPercentage["party1"] = 0
    Local.LastHealthPercentage["party2"] = 0
    Local.LastHealthPercentage["party3"] = 0
    Local.LastHealthPercentage["party4"] = 0
    Local.LastManaPercentage["player"] = UnitMana("player") / UnitManaMax("player")
end


---[[-----------------------------------------------------------
-- Section IV: Enabling or Disabling the Addon.     	      --
----------------------------------------------------------------

function VitalWatch:Enable()
	self:RegisterEvent("UNIT_HEALTH")
	self:RegisterEvent("UNIT_MANA")
end

-- Disable() is not needed if all you are doing in Enable() is registering events
-- and hooking functions. Ace will automatically unregister and unhook these.
-- function VitalWatch:Disable()
-- end

---[[-----------------------------------------------------------
-- Section V: Debugging Functions.   	      	     	      --
----------------------------------------------------------------

---[[-----------------------------------------------------------
-- Section V: Utility Functions.   	      	     	      --
----------------------------------------------------------------

function VitalWatch:FloatMsg(msg, colour)
	local r, g, b = 1,1,1
	
	colour = string.lower(colour)
    	if colour == "red" then r,g,b = 1,0,0 end
	if colour == "green" then r,g,b = 0,1,0 end
	if colour == "blue" then r,g,b = 0,0,1 end
	if colour == "magenta" then r,g,b = 1,0,1 end
	if colour == "yellow" then r,g,b = 1,1,0 end
	if colour == "cyan" then r,g,b = 0,1,1 end
	
	VitalWatchMessageFrame:AddMessage(msg, r, g, b, 1, 3)
end

function VitalWatch:Other_VitalCheck(vital, unit, tag)
	local percentage = nil
		
	        percentage = getglobal("Unit" .. vital)(unit) / getglobal("Unit" .. vital .. "Max")(unit)
            	if percentage < self:Get( "Low" .. vital .. "Threshold") and Local["Last" .. vital .. "Percentage"][unit] >= self:Get( "Low".. vital .."Threshold") then
			VitalWatch:FloatMsg(UnitName(unit) .. VitalWatchLocale["Low_" .. vital .. "_Floating_Message"] .. tag, Local["Low" .. vital .. "Colour"])
			
			if self:Get( "Low".. vital .."Sound") then
				PlaySoundFile( self:Get( "Low".. vital .."Sound") )
			end

			if self:Get( "Low".. vital .."PartySpam") then
				SendChatMessage( VitalWatchLocale.Title .. ": " .. UnitName(unit) .. VitalWatchLocale["Low_" .. vital .. "_Floating_Message"] .. tag, "PARTY" )
			end
				
                end
		if percentage < self:Get( "Crit".. vital .."Threshold") and Local["Last" .. vital .. "Percentage"][unit] >= self:Get( "Crit".. vital .."Threshold") then
			VitalWatch:FloatMsg(UnitName(unit) .. VitalWatchLocale["Crit_" .. vital .. "_Floating_Message"] .. tag, Local["Crit" .. vital .. "Colour"])
		
			if self:Get( "Crit".. vital .."Sound") then
				PlaySoundFile( self:Get( "Crit".. vital .."Sound") )
			end

			if self:Get( "Crit".. vital .."PartySpam") then
				SendChatMessage( VitalWatchLocale.Title .. ": " .. UnitName(unit) .. VitalWatchLocale["Crit_" .. vital .. "_Floating_Message"] .. tag, "PARTY" )
			end
		end
		Local["Last" .. vital .. "Percentage"][unit] = percentage
end

function VitalWatch:Player_VitalCheck(vital)
	local percentage = nil
            	percentage = getglobal("Unit" .. vital)("player") / getglobal("Unit" .. vital .. "Max")("player")
            	if percentage < self:Get( "Low" .. vital .. "Threshold") and Local["Last" .. vital .. "Percentage"]["player"] >= self:Get( "Low".. vital .."Threshold") then
			VitalWatch:FloatMsg(VitalWatchLocale["Self_Low_" .. vital .. "_Floating_Message"], Local["Low" .. vital .. "Colour"])
			
		    	if self:Get( "Low" .. vital .. "Emote") and not CastingBarFrame.casting and not CastingBarFrame.channeling then
				-- let's assume non-voice emotes have at least one space in them
				if not string.find( self:Get( "Low" .. vital .. "Emote"), "%s") then
					DoEmote(self:Get( "Low".. vital .."Emote"))
				else
					SendChatMessage( self:Get( "Low".. vital .."Emote"), "EMOTE" )
				end
		    	else
				if self:Get( "Low".. vital .."Sound") then
					PlaySoundFile( self:Get( "Low".. vital .."Sound") )
				end
		    	end
                    	if self:Get( "Low".. vital .."PartyMsg") and GetNumPartyMembers() > 0 then
                        	SendChatMessage( VitalWatchLocale.Title .. ": " .. self:Get( "Low".. vital .."PartyMsg"), "PARTY" )
                    	end
                end
		if percentage < self:Get( "Crit".. vital .."Threshold") and Local["Last" .. vital .. "Percentage"]["player"] >= self:Get( "Crit".. vital .."Threshold") then
			VitalWatch:FloatMsg(VitalWatchLocale["Self_Crit_" .. vital .. "_Floating_Message"], Local["Crit" .. vital .. "Colour"])
			
		    	if self:Get( "Crit".. vital .."Emote") and not CastingBarFrame.casting and not CastingBarFrame.channeling then
				-- let's assume non-voice emotes have at least one space in them
				if not string.find( self:Get( "Crit".. vital .."Emote"), "%s") then
					DoEmote(self:Get( "Crit".. vital .."Emote"))
				else
					SendChatMessage( self:Get( "Crit".. vital .."Emote"), "EMOTE" )
				end
		    	else
				if self:Get( "Crit".. vital .."Sound") then
					PlaySoundFile( self:Get( "Crit".. vital .."Sound") )
				end
			end
                    	if self:Get( "Crit".. vital .."PartyMsg") and GetNumPartyMembers() > 0 then
                        	SendChatMessage( VitalWatchLocale.Title .. ": " .. self:Get( "Crit".. vital .."PartyMsg"), "PARTY" )
                    	end
		end
		Local["Last" .. vital .. "Percentage"]["player"] = percentage
end

---[[-----------------------------------------------------------
-- Section VI: Main Processing.   	      	     	      --
----------------------------------------------------------------

---[[-----------------------------------------------------------
-- Section VII: Event Processing.     	      		      --
----------------------------------------------------------------
	
function VitalWatch:UNIT_HEALTH()
	if arg1 then
		-- *&^$ Hunters and faking us out with Feign Death
		if not ( UnitHealth(arg1) <= 0 and not UnitIsDead(arg1) ) then
		
			if arg1 == "player" then VitalWatch:Player_VitalCheck("Health")
			elseif self:Get( "HealthPetWatch") and string.find(arg1, "pet",1,plain) then
				if arg1 == "pet" then
					VitalWatch:Other_VitalCheck("Health", arg1, VitalWatchLocale.MyPetTag)
				elseif self:Get( "HealthPartyWatch") then
					VitalWatch:Other_VitalCheck("Health", arg1, VitalWatchLocale.PetTag)
				end
			elseif self:Get( "HealthPartyWatch") and UnitInParty(arg1) then 
				VitalWatch:Other_VitalCheck("Health", arg1, "")
			end
		end
	elseif not self:Get( "NoError" ) then
		self:Msg( VitalWatchLocale.ERROR_ARG1 )
	end
end

function VitalWatch:UNIT_MANA()
	-- UNIT_MANA is fired when a Druid shapeshifts, yet the Druid has 0 Mana for Cat and Bear!
	if arg1 then
		if arg1 == "player" and UnitPowerType(arg1) == 0 then
			VitalWatch:Player_VitalCheck("Mana")
		end
	elseif not self:Get( "NoError" ) then
		self:Msg( VitalWatchLocale.ERROR_ARG1 )
	end
end

---[[-----------------------------------------------------------
-- Section VIII: Chat Command Handlers    	      	      --
----------------------------------------------------------------

function VitalWatch:SetThreshold(opt1, num)
	num = tonumber(num) / 100
	self:Set( opt1 .. "Threshold", num, VitalWatchLocale.CHATMAP[ opt1 .. "Threshold"])
	self.cmd:status( num, opt1 .. "Threshold" )
end
function VitalWatch:SetLowHealthThreshold(num) 
	VitalWatch:SetThreshold("LowHealth", num)
end
function VitalWatch:SetCritHealthThreshold(num) 
	VitalWatch:SetThreshold("CritHealth", num)
end
function VitalWatch:SetLowManaThreshold(num)
	VitalWatch:SetThreshold("LowMana", num)
end
function VitalWatch:SetCritManaThreshold(num) 
	VitalWatch:SetThreshold("CritMana", num)
end

function VitalWatch:ToggleHealthPartyWatch()
	self:Toggle( "HealthPartyWatch", VitalWatchLocale.CHATMAP.HealthPartyWatch )
end

function VitalWatch:ToggleHealthPetWatch()
	self:Toggle( "HealthPetWatch", VitalWatchLocale.CHATMAP.HealthPetWatch )
end

function VitalWatch:ToggleLowHealthPartySpam()
	self:Toggle( "LowHealthPartySpam", VitalWatchLocale.CHATMAP.LowHealthPartySpam )
end

function VitalWatch:ToggleCritHealthPartySpam()
	self:Toggle( "CritHealthPartySpam", VitalWatchLocale.CHATMAP.CritHealthPartySpam )
end

function VitalWatch:SetTextVariables(opt1, opt2, text)
	if text and string.len(text) > 0 then
		self:Set( opt1 .. opt2, text )
	else
		self:Set( opt1 .. opt2, nil )
	end
	self:ReportMsg( self:Get( opt1 .. opt2 ), VitalWatchLocale.CHATMAP[ opt1 .. opt2 ] )
end
function VitalWatch:DisableOpt(opt)
	VitalWatch:SetTextVariables("LowHealth", opt, nil)
	VitalWatch:SetTextVariables("CritHealth", opt, nil)
	VitalWatch:SetTextVariables("LowMana", opt, nil)
	VitalWatch:SetTextVariables("CritMana", opt, nil)
end
function VitalWatch:SetLowHealthPartyMsg(text) 
	VitalWatch:SetTextVariables("LowHealth", "PartyMsg", text)
end
function VitalWatch:SetCritHealthPartyMsg(text) 
	VitalWatch:SetTextVariables("CritHealth", "PartyMsg", text)
end
function VitalWatch:SetLowManaPartyMsg(text) 
	VitalWatch:SetTextVariables("LowMana", "PartyMsg", text)
end
function VitalWatch:SetCritManaPartyMsg(text) 
	VitalWatch:SetTextVariables("CritMana", "PartyMsg", text)
end
function VitalWatch:DisablePartyMsg()
	VitalWatch:DisableOpt("PartyMsg")
end	
function VitalWatch:SetLowHealthEmote(text) 
	VitalWatch:SetTextVariables("LowHealth", "Emote", text)
end
function VitalWatch:SetCritHealthEmote(text) 
	VitalWatch:SetTextVariables("CritHealth", "Emote", text)
end
function VitalWatch:SetLowManaEmote(text) 
	VitalWatch:SetTextVariables("LowMana", "Emote", text)
end
function VitalWatch:SetCritManaEmote(text) 
	VitalWatch:SetTextVariables("CritMana", "Emote", text)
end
function VitalWatch:DisableEmote()
	VitalWatch:DisableOpt("Emote")
end
function VitalWatch:SetLowHealthSound(text) 
	if text and string.len(text) > 0 then
		VitalWatch:SetTextVariables("LowHealth", "Sound",  VitalWatchLocale.SoundPath .. text .. ".wav")
	else
		VitalWatch:SetTextVariables("LowHealth", "Sound", nil)
	end
end
function VitalWatch:SetCritHealthSound(text) 
	if text and string.len(text) > 0 then
		VitalWatch:SetTextVariables("CritHealth", "Sound",  VitalWatchLocale.SoundPath .. text .. ".wav")
	else
		VitalWatch:SetTextVariables("CritHealth", "Sound", nil)
	end
end
function VitalWatch:SetLowManaSound(text) 
	if text and string.len(text) > 0 then
		VitalWatch:SetTextVariables("LowMana", "Sound",  VitalWatchLocale.SoundPath .. text .. ".wav")
	else
		VitalWatch:SetTextVariables("LowMana", "Sound", nil)
	end
end
function VitalWatch:SetCritManaSound(text) 
	if text and string.len(text) > 0 then
		VitalWatch:SetTextVariables("CritMana", "Sound",  VitalWatchLocale.SoundPath .. text .. ".wav")
	else
		VitalWatch:SetTextVariables("CritMana", "Sound", nil)
	end
end
function VitalWatch:DisableSound()
	VitalWatch:DisableOpt("Sound")
end

function VitalWatch:Report()
	self:ReportMap(VitalWatchLocale.CHATMAP)
end

function VitalWatch:ToggleErrors()
	self:Toggle( "NoError", VitalWatchLocale.CHATMAP.NoError )
end
---[[-----------------------------------------------------------
-- Section Omega: Register the Addon    	      	      --
----------------------------------------------------------------

VitalWatch:RegisterForLoad()

