VitalWatchLocale = {}
if( not ace:LoadTranslation("VitalWatch") ) then

---[[-----------------------------------------------------------
-- Section II: AddOn Information.                             --
----------------------------------------------------------------

VitalWatchLocale.Title   = "VitalWatch"
VitalWatchLocale.Version = "1.42"
VitalWatchLocale.Desc    = "VitalWatch is a health/mana monitoring system for yourself and your party."


---[[-----------------------------------------------------------
-- Section III: Register Global Variables and Functions.      --
----------------------------------------------------------------
ace:RegisterGlobals({
	version = 1.02, -- AceUtil version you are using
	ACEG_MAP_ONOFF 	= {[0]="|cffff5050Off|r",[1]="|cff00ff00On|r"},
   	-- For use by Err.
   	ACEG_ERROR     = "%s is invalid, valid values are %s.",
   	ACEG_OVERZERO  = "over 0 only", 

   	ACEG_RESETINFO = "Are you sure?  Please type '%s reset confirm' to proceed.",
   	ACEG_DORESET   = "All option defaults have been restored.", 
})

---[[-----------------------------------------------------------
-- Section IV: Chat Option Variables.                         --
----------------------------------------------------------------

VitalWatchLocale.ChatCmd = {"/vw", "/vitalwatch"}

-- These are the Chat Options. Localize them for your language.
VitalWatchLocale.ChatOptions = {
	{
		option         = "reset",
		desc           = "Reset all settings back to their defaults.",
		method	       = "Reset"
	},
	{
		option         = "threshold",
		desc           = "Set the low or critical threshold for health or mana.",
		input          = TRUE,
		args           = {
				{
					option	= "lowhealth",
					desc 	= "Set the threshold for low health.",
					method 	= "SetLowHealthThreshold",
					input 	= TRUE
				},
				{
					option 	= "crithealth",
					desc	= "Set the threshold for critical health.",
					method 	= "SetCritHealthThreshold",
					input 	= TRUE
				},
				{
					option	= "lowmana",
					desc 	= "Set the threshold for low mana.",
					method 	= "SetLowManaThreshold",
					input 	= TRUE
				},
				{
					option 	= "critmana",
					desc	= "Set the threshold for critical mana.",
					method 	= "SetCritManaThreshold",
					input 	= TRUE
				}
					
		}
	},
	{
		option         = "partywatch",
		desc           = "Toggle whether or not your party is watched as well as yourself for low/critical health.",
		method         = "ToggleHealthPartyWatch"
	},
	{
		option         = "petwatch",
		desc           = "Toggle whether or not pets are watched for low/critical health. PartyWatch must be toggled to watch party pets.",
		method         = "ToggleHealthPetWatch"
	},
	{	option         = "partyspam",
		desc           = "Toggle whether or not you want to spam party with your low/critical health messages.",
		input	       = TRUE,
		args           = {
				{
					option 	= "help",
					desc	= "The messages sent are the same ones you get at the top of the screen for party members and pets ( \"partymsg\" handles messages about you). If PartyWatch is disabled, party health will not be announced. If PetWatch is disabled, pet health will not be announced. If both are disabled, this option has no effect."
				},
				{
					option	= "lowhealth",
					desc 	= "Enable announcements of low health.",
					method 	= "ToggleLowHealthPartySpam"
				},
				{
					option 	= "crithealth",
					desc	= "Enable announcements of critical health.",
					method 	= "ToggleCritHealthPartySpam"
				}
		}
	},
	{
		option         = "partymsg",
		desc           = "Change how messages are sent to your party when you have low/critical health/mana.",
		input          = TRUE,
		args           = {
				{
					option 	= "help",
					desc	= "Leave the message blank to disable."
				},
				{
					option 	= "disable",
					desc 	= "Disable this option entirely.",
					method  = "DisablePartyMsg"
				},
				{
					option	= "lowhealth",
					desc 	= "Set the message for low health.",
					method 	= "SetLowHealthPartyMsg"
				},
				{
					option 	= "crithealth",
					desc	= "Set the message for critical health.",
					method 	= "SetCritHealthPartyMsg"
				},
				{
					option	= "lowmana",
					desc 	= "Set the message for low mana.",
					method 	= "SetLowManaPartyMsg"
				},
				{
					option 	= "critmana",
					desc	= "Set the message for critical mana.",
					method 	= "SetCritManaPartyMsg"
				}
		}
	},
	{
		option         = "emote",
		desc           = "Change what emotes you use upon low/critical health/mana.",
		input          = TRUE,
		args           = {
				{
					option 	= "help",
					desc	= "Leave the emote blank to disable. Don't include the slash. If a voice emote, this overrides any sound set. Please note voice emotes will not be played if you are casting or channeling, since that would interrupt your spellcasting."
				},
				{
					option 	= "disable",
					desc 	= "Disable this option entirely.",
					method  = "DisableEmote"
				},
				{
					option	= "lowhealth",
					desc 	= "Set the emote for low health.",
					method 	= "SetLowHealthEmote"
				},
				{
					option 	= "crithealth",
					desc	= "Set the emote for critical health.",
					method 	= "SetCritHealthEmote"
				},
				{
					option	= "lowmana",
					desc 	= "Set the emote for low mana.",
					method 	= "SetLowManaEmote"
				},
				{
					option 	= "critmana",
					desc	= "Set the emote for critical mana.",
					method 	= "SetCritManaEmote"
				}
		}
	},
	{
		option         = "sound",
		desc           = "Set what sound (its filename) used to alert you on health/mana changes.",
		input          = TRUE,
		args           = {
				{
					option 	= "help",
					desc	= "Leave the sound filename blank to disable. Don't include the .wav extension. Please note a voice emote overrides any sound set."
				},
				{
					option 	= "disable",
					desc 	= "Disable this option entirely.",
					method  = "DisableSound"
				},
				{
					option	= "lowhealth",
					desc 	= "Set the sound for low health.",
					method 	= "SetLowHealthSound"
				},
				{
					option 	= "crithealth",
					desc	= "Set the sound for critical health.",
					method 	= "SetCritHealthSound"
				},
				{
					option	= "lowmana",
					desc 	= "Set the sound for low mana.",
					method 	= "SetLowManaSound"
				},
				{
					option 	= "critmana",
					desc	= "Set the sound for critical mana.",
					method 	= "SetCritManaSound"
				}
		}
	},
	{
		option		= "noerror",
		desc		= "Toggle whether or not to show advanced error messages.",
		method		= "ToggleErrors"
	}
}

-- These are the messages given when successfully getting or setting an option.
VitalWatchLocale.CHATMAP = {
	LowHealthThreshold 	= "Low Health Threshold",
	CritHealthThreshold 	= "Critical Health Threshold",
	LowManaThreshold 	= "Low Mana Threshold",
	CritManaThreshold 	= "Critical Mana Threshold",
	HealthPartyWatch	= "Watching Party",
	HealthPetWatch		= "Watching Pet(s)",
	LowHealthPartySpam	= "Announcing Low Health For Party Members and/or Pet(s)",
	CritHealthPartyMsg	= "Critical Health Party Message",
	LowManaPartyMsg 	= "Low Mana Party Message",
	CritManaPartyMsg 	= "Critical Mana Party Message",
	LowHealthEmote 		= "Low Health Emote",
	CritHealthEmote		= "Critical Health Emote",
	LowManaEmote 		= "Low Mana Emote",
	CritManaEmote 		= "Critical Mana Emote",
	LowHealthSound 		= "Low Health Sound",
	CritHealthSound		= "Critical Health Sound",
	LowManaSound 		= "Low Mana Sound",
	CritManaSound 		= "Critical Mana Sound",
	NoError			= "Error display"
}

---[[-----------------------------------------------------------
-- Section V: Other Variables.                    	      --
----------------------------------------------------------------

VitalWatchLocale.Self_Low_Health_Floating_Message 	= "Your health is low!"
VitalWatchLocale.Self_Crit_Health_Floating_Message 	= "Your health is CRITICAL!"
VitalWatchLocale.Self_Low_Mana_Floating_Message 	= "Your mana is low!"
VitalWatchLocale.Self_Crit_Mana_Floating_Message 	= "Your mana is CRITICAL!"

VitalWatchLocale.Low_Health_Floating_Message 		= "'s health is low!"
VitalWatchLocale.Crit_Health_Floating_Message		= "'s health is CRITICAL!"
VitalWatchLocale.MyPetTag				= " (my pet)"
VitalWatchLocale.PetTag					= " (pet)"

VitalWatchLocale.DEFAULT_LowHealthPartyMsg 		= "My health is low!"
VitalWatchLocale.DEFAULT_CritHealthPartyMsg		= "My health is CRITICAL!"
VitalWatchLocale.DEFAULT_LowManaPartyMsg		= "My mana is low!"
VitalWatchLocale.DEFAULT_CritManaPartyMsg		= "My mana is CRITICAL!"

VitalWatchLocale.DEFAULT_LowHealthEmote			= "healme"
VitalWatchLocale.DEFAULT_CritHealthEmote		= "helpme"
VitalWatchLocale.DEFAULT_LowManaEmote			= "is low on mana!"
VitalWatchLocale.DEFAULT_CritManaEmote			= "oom"

VitalWatchLocale.ERROR_ARG1 = " |cffff0000ERROR in OnEvent - arg1 is nil. One of your other addons is most likely causing this. Type in /vw noerror to disable this message.|r"

VitalWatchLocale.SoundPath = "Interface\\AddOns\\VitalWatch\\sounds\\"

---[[-----------------------------------------------------------
-- Section Omega: Closure.                                    --
----------------------------------------------------------------

end
